@@ -121,6 +121,7 @@ public:
 
     // Set the log to be available to stages.
     void setLog(const LogPtr& log);
+    LogPtr log() const;
 
     QuickInfo preview() const;
     void prepare() const;
@@ -129,6 +130,7 @@ public:
     void executeStream(StreamPointTable& table);
     void validateStageOptions() const;
     bool pipelineStreamable() const;
+    bool hasReader() const;
 
     // Get the resulting point views.
     const PointViewSet& views() const
